@@ -10,7 +10,7 @@ README = (HERE / "README.md").read_text()
 # This call to setup() does all the work
 setup(
     name="funcopy",
-    version="0.0.0",
+    version="0.2.0",
     description="funcopy: copy a func",
     long_description=README,
     long_description_content_type="text/markdown",
@@ -20,11 +20,10 @@ setup(
     classifiers=[
         "License :: OSI Approved :: MIT License",
         "Programming Language :: Python :: 3",
-        "Programming Language :: Python :: 3.7",
     ],
     packages=["funcopy"],
     include_package_data=True,
-    install_requires=['types'],
+    install_requires=[],
 )
 
 
